# Changelog

## 0.6 - 2014/03/06

New features:

* add a new assignment template tag: `get_page_url_for_language` 
* add a custom `SetLanguageView` to switch languages for a page or category (or an inherited model detail view)

Fix minor issues:

* issue #13: add tinyMCE styles to page and categorie detail view templates.
* issue #18: we now raise a warning message when disqus is not configured instead of an `ImproperlyConfigured` exception.
* issue #21: pages from other languages are now displayed instead of raising a 404 error.

## 0.5.4 - 2013/12/19

Fix issue #16: when asking for category pages, default ordering (position) was overridden. This is now fixed.

## 0.5.3 - 2013/12/03

Fix issue #15: categories can now be related to objects that do not inherit from the Page model, and the get_pages method will list them.

## 0.5.2 - 2013/11/22

Fix social media page sharing logic: everything stands in the `td_cms/partials/page_social.html` template. Feel free to add your killer plugin.

## 0.5.1 - 2013/11/15

Fix requirements in setup.py installation script

## 0.5 - 2013/11/11

First public stable release

## TODO

* Write the doc :)
